// Copyright 1999-2017. Parallels IP Holdings GmbH. All Rights Reserved.
import { createElement, Component } from '@plesk/ui-library';
import classNames from 'classnames';

class Dropdown extends Component {
    constructor(props) {
        super(props);
        this.state = {
            opened: false,
            value: this.props.value
        }
    }

    componentDidMount() {
        this.refs.toggler.addEventListener('click', () => {
            this.toggle();
        });
        this.refs.toggler.addEventListener('click', event => event.stopPropagation());
        this.props.values.forEach((value, key) => {
            this.refs[`option${key}`].addEventListener('click', () => {
                this.toggle();
                this.setValue(value);
            });
        });
    }

    setValue(value) {
        this.setState({ value });
        this.props.onChange(value);
    }

    toggle() {
        const opened = !this.state.opened;
        this.setState({ opened });
    }

    render() {
        return (
            <div className={classNames('dropdown', this.state.opened && 'open')}>
                <div className="input-group">
                    <input type="text" className="form-control" value={this.state.value}
                        onChange={event => this.setValue(event.target.value)}
                    />
                    <span className="input-group-btn" ref="toggler">
                        <span className="btn dropdown-toggle">
                            <button type="button"><span className="caret" /></button>
                        </span>
                    </span>
                </div>
                <ul className="dropdown-menu" ref="menu">
                    {this.props.values.map((value, key) => (
                        <li key={key} ref={`option${key}`}>
                            <a>{value}</a>
                        </li>
                    ))}
                </ul>
            </div>
        );
    }
}

export default Dropdown;
