// Copyright 1999-2017. Parallels IP Holdings GmbH. All Rights Reserved.
import { render, createElement, Component } from '@plesk/ui-library';
import FormRow from './FormRow';

class RunScriptForm extends Component {
    constructor(props) {
        super(props);
        this.state = {
            options: '',
            errorCode: 0,
            output: '',
            running: false
        };
    }

    render() {
        const locale = Jsw.Locale.getSection('components.run-script-popup');

        const hint = locale.lmsg('optionsDescription', {
            examples: ['build', 'test'].map(
                (example) => '<br>&nbsp;&nbsp;&nbsp;&nbsp;' + example
            ).join('')
        });

        return (
            <div>
                <FormRow single name={locale.lmsg('options')} hint={hint}>
                    <input className="input-text f-max-size" type="text" ref="options" value={this.state.options} onChange={(event) => {
                        this.setState({
                            options: event.target.value
                        });
                    }}/>
                </FormRow>
                <FormRow error={!!this.state.errorCode} single name={locale.lmsg('output')}>
                    <pre className="console-output console-output-wide">
                        {this.state.output}{this.state.running ? <span className="cursor animation-blink" /> : null}
                    </pre>
                </FormRow>
            </div>
        );
    }
}

export default Class.create(Jsw.Popup, {
    _initConfiguration: function ($super, {url, options = ""}) {
        const locale = Jsw.Locale.getSection('components.run-script-popup');

        $super({
            popupCls: 'popup-panel popup-panel-xl',
            title: locale.lmsg('title'),
            locale: locale,
            closeButtonEnabled: true,
            buttons: [{
                title: locale.lmsg('run'),
                class: 'action',
                handler: this._onRun.bind(this)
            }]
        });

        this._url = url;
        this._options = options;
    },

    _initComponentElement: function ($super) {
        $super();

        const form = this._componentElement.down('form');
        form.observe('submit', (event) => {
            event.preventDefault();
            this._onRun();
        });

        const container = document.createElement('div');
        this.form = render(<RunScriptForm />, container);
        form.insertBefore(container.firstElementChild, form.firstElementChild);
    },

    show: function ($super) {
        $super();
        this.form.refs.options.focus();
        this._runButtonEl = this._componentElement.down('.btns-box .btn.action');
    },

    _onRun: function () {
        this.form.setState({
            running: true
        });
        this._runButtonEl.addClassName('disabled');
        this._runButtonEl.down('button').disabled = true;
        this._runButtonEl.down('button').update('<span class="wait">' + this.lmsg('pleaseWait') + '</span>');

        new Ajax.Request(this._url, {
            method: 'post',
            parameters: {
                options: this.form.state.options
            },
            onSuccess: this._onSuccess.bind(this)
        });
    },

    _onSuccess: function ({responseText}) {
        const data = responseText.evalJSON();

        if (data.redirect) {
            Jsw.redirect(data.redirect);
            return;
        }

        this.form.setState({
            errorCode: data.code,
            output: data.stdout + data.stderr,
            running: false
        });
        this._runButtonEl.removeClassName('disabled');
        this._runButtonEl.down('button').disabled = false;
        this._runButtonEl.down('button').update(this.lmsg('run'));
    }
});
