// Copyright 1999-2017. Parallels IP Holdings GmbH. All Rights Reserved.
import { createElement, Component } from '@plesk/ui-library';
import classNames from 'classnames';

export default class SidebarPanel extends Component {
    constructor(props) {
        super(props);
        this.stateCookieName = this.props.id + '-hidden';
        this.state = {
            collapsed: Jsw.Cookie.get(this.stateCookieName) !== null
        };
    }

    toggle() {
        const collapsed = !this.state.collapsed;
        this.setState({ collapsed });

        if (collapsed) {
            Jsw.Cookie.setPermanent(this.stateCookieName, 1, '/');
        } else {
            Jsw.Cookie.remove(this.stateCookieName, '/');
        }
    }

    render() {
        const { title, className, children } = this.props;

        return (
            <div className={classNames('panel', className, 'panel-collapsible', this.state.collapsed ? 'panel-collapsed' : 'panel-expanded')}>
                <div className="panel-wrap">
                    {title && (
                        <div className="panel-heading" onClick={this.toggle.bind(this)}>
                            <div className="panel-heading-wrap">
                                <span className="panel-control"><i /></span>
                                <h4 className="panel-heading-name">
                                    <span>{title}</span>
                                </h4>
                            </div>
                        </div>
                    )}
                    <div className="panel-content">
                        <div className="panel-content-wrap">
                            {children}
                        </div>
                    </div>
                </div>
            </div>
    );
    }
}
